diff --git a/conf/airframes/OPENUAS/openuas_wltech_xk_a160.xml b/conf/airframes/OPENUAS/openuas_wltech_xk_a160.xml
index 68040ebe55..ee988e069d 100644
--- a/conf/airframes/OPENUAS/openuas_wltech_xk_a160.xml
+++ b/conf/airframes/OPENUAS/openuas_wltech_xk_a160.xml
@@ -10,24 +10,22 @@
+ ESC: FTV LittleBee 20A Opto Pro with custom firmware
+ BEC: 2.5A small BEC
+ RCRX: OpenRXSR Receiver
- + AIRSPEED: No airspeed (Yet)
+ + AIRSPEED: No airspeed
+ TELEMETRY: Si10xx Chip based with firmware enabeling PPRZ RSSI message
- + RANGER: None ATM
+ + RANGER: None
+ MOTOR: Default
+ PROP: Default
NOTES:
- + Default CoG is wrong and WAY off, tail heavy, we've modified AC body so that the battery can fit fully in front
+ + With original airframe the default CoG is wrong and WAY off, tail heavy, we've modified AC body so that the battery can fit fully in front
+ AP is rotated on Z 45 degrees counterclockwise and flipped 180 degrees
+ Telemetry powered via BEC on flightcontrollen (100mAh max + MCU 60mAh is less than 250mAh, the max the DC converter can handle )
- + Flashing the firmware done with Black Magic Probe (BMP) adapter
- + A GNSS device with magneto on it is used
+ + Flashing the firmware performed with Black Magic Probe (BMP) adapter
+ + A GNSS device with magneto on same PCB is used
+ Uses PAPARAZZI "standard" radio channel settings
+ A 650mAh battery, expect flighttimes of ~15 minutes at 10m/s
-
-
- Launching
+ Launching
+ 1) Set TX to AUTO2, or if no TX it is AUTO2
2) Move nose to ground
3) wait until prop spins after a second or so,
@@ -37,8 +35,8 @@ NOTES:
-
-
+
+
@@ -58,11 +56,11 @@ NOTES:
-
+
+
+
+
+
@@ -114,10 +112,11 @@ NOTES:
-
+
-
+
+
@@ -128,18 +127,20 @@ NOTES:
-
+
+
+
@@ -162,7 +163,7 @@ NOTES:
-
+
@@ -202,33 +203,33 @@ NOTES:
-
+
-
+
-
+
-
-
-
+
+
+
-
+
-
+
@@ -237,7 +238,7 @@ NOTES:
-
+
@@ -259,14 +260,14 @@ NOTES:
-
+
-
+ -->
+
@@ -320,7 +321,7 @@ NOTES:
-
+
@@ -427,7 +428,6 @@ NOTES:
-
@@ -452,7 +452,6 @@ NOTES:
-
@@ -505,7 +504,6 @@ NOTES:
-
@@ -528,16 +526,15 @@ NOTES:
Or place a reistor on top. We only had a 7k0 lying around at the time, so our multiplication factor is now ~0.0023872f
-->
-
-
+
-
+
@@ -563,7 +560,7 @@ NOTES:
-
+
@@ -582,6 +579,12 @@ NOTES:
+
+
diff --git a/conf/telemetry/OPENUAS/openuas_fixedwing_imu_rc.xml b/conf/telemetry/OPENUAS/openuas_fixedwing_imu_rc.xml
index 028bb3aa8a..271e11f18a 100644
--- a/conf/telemetry/OPENUAS/openuas_fixedwing_imu_rc.xml
+++ b/conf/telemetry/OPENUAS/openuas_fixedwing_imu_rc.xml
@@ -3,13 +3,13 @@
-
+
-
+
-
-
+
+
@@ -24,18 +24,18 @@
-
-
-
+
+
+
-
-
+
+
-
-
+
+
@@ -50,7 +50,6 @@
-
diff --git a/sw/airborne/boards/lisa_mxs/chibios/v1.0/mcuconf.h b/sw/airborne/boards/lisa_mxs/chibios/v1.0/mcuconf.h
index 04a384b491..ae4f82e4e0 100644
--- a/sw/airborne/boards/lisa_mxs/chibios/v1.0/mcuconf.h
+++ b/sw/airborne/boards/lisa_mxs/chibios/v1.0/mcuconf.h
@@ -244,7 +244,7 @@
* ICU driver system settings.
*/
#define STM32_ICU_USE_TIM1 TRUE
-#define STM32_ICU_USE_TIM2 FALSE
+#define STM32_ICU_USE_TIM2 TRUE //for PPM input support
#define STM32_ICU_USE_TIM3 FALSE
#define STM32_ICU_USE_TIM4 FALSE
#define STM32_ICU_USE_TIM5 FALSE
diff --git a/sw/airborne/boards/lisa_mxs/chibios/v1.0/board.h b/sw/airborne/boards/lisa_mxs/chibios/v1.0/board.h
index b57d039e00..f70cf24440 100644
--- a/sw/airborne/boards/lisa_mxs/chibios/v1.0/board.h
+++ b/sw/airborne/boards/lisa_mxs/chibios/v1.0/board.h
@@ -175,8 +175,8 @@
PIN_ODR_HIGH(13) | \
PIN_ODR_HIGH(14) | \
PIN_ODR_HIGH(15))
-#define VAL_GPIOA_AFRL (PIN_AFIO_AF(0, 2) | \
- PIN_AFIO_AF(1, 2) | \
+#define VAL_GPIOA_AFRL (PIN_AFIO_AF(0, 0) | \
+ PIN_AFIO_AF(1, 1) | \
PIN_AFIO_AF(2, 7) | \
PIN_AFIO_AF(3, 7) | \
PIN_AFIO_AF(4, 5) | \
@@ -185,7 +185,7 @@
PIN_AFIO_AF(7, 5))
#define VAL_GPIOA_AFRH (PIN_AFIO_AF(8, 0) | \
PIN_AFIO_AF(9, 7) | \
- PIN_AFIO_AF(10, 1) | \
+ PIN_AFIO_AF(10, 7) | \
PIN_AFIO_AF(11, 10) | \
PIN_AFIO_AF(12, 10) | \
PIN_AFIO_AF(13, 0) | \
@@ -200,8 +200,8 @@
* PB3 - Digital input (JTAG_TDO/SWD)
* PB4 - Open Drain output 50MHz (LED2)
* PB5 - Digital input (IMU_MAG_DRDY)
* PB6 - Alternate Open Drain output 2MHz (SERVO7-Timer4Ch1)/USART1_TX
* PB7 - Alternate Open Drain output 2MHz (SERVO8-Timer4Ch2)/USART1_RX
* PB8 - Digital input. (CAN_RX)
* PB9 - Open Drain output 50MHz. (CAN_TX)
* PB10 - Alternate Open Drain output 2MHz.(I2C2_SCL)
@@ -237,8 +237,8 @@
PIN_OTYPE_OPENDRAIN(7) | \
PIN_OTYPE_PUSHPULL(8) | \
PIN_OTYPE_OPENDRAIN(9) | \
- PIN_OTYPE_OPENDRAIN(10) | \
- PIN_OTYPE_OPENDRAIN(11) | \
+ PIN_OTYPE_PUSHPULL(10) | \
+ PIN_OTYPE_PUSHPULL(11) | \
PIN_OTYPE_PUSHPULL(12) | \
PIN_OTYPE_PUSHPULL(13) | \
PIN_OTYPE_PUSHPULL(14) | \
@@ -253,8 +253,8 @@
PIN_OSPEED_50M(7) | \
PIN_OSPEED_50M(8) | \
PIN_OSPEED_50M(9) | \
- PIN_OSPEED_2M(10) | \
- PIN_OSPEED_2M(11) | \
+ PIN_OSPEED_50M(10) | \
+ PIN_OSPEED_50M(11) | \
PIN_OSPEED_50M(12) | \
PIN_OSPEED_50M(13) | \
PIN_OSPEED_50M(14) | \
@@ -265,8 +265,8 @@
PIN_PUPDR_FLOATING(3) | \
PIN_PUPDR_FLOATING(4) | \
PIN_PUPDR_FLOATING(5) | \
- PIN_PUPDR_FLOATING(6) | \
- PIN_PUPDR_FLOATING(7) | \
+ PIN_PUPDR_PULLUP(6) | \
+ PIN_PUPDR_PULLUP(7) | \
PIN_PUPDR_FLOATING(8) | \
PIN_PUPDR_FLOATING(9) | \
PIN_PUPDR_FLOATING(10) | \
@@ -301,8 +301,8 @@
PIN_AFIO_AF(7, 4))
#define VAL_GPIOB_AFRH (PIN_AFIO_AF(8, 9) | \
PIN_AFIO_AF(9, 9) | \
- PIN_AFIO_AF(10, 4) | \
- PIN_AFIO_AF(11, 4) | \
+ PIN_AFIO_AF(10, 7) | \
+ PIN_AFIO_AF(11, 7) | \
PIN_AFIO_AF(12, 0) | \
PIN_AFIO_AF(13, 5) | \
PIN_AFIO_AF(14, 5) | \
@@ -312,7 +312,7 @@
* Port C setup:
* PC0 - Analog input (ADC2)
* PC1 - Analog input (ADC3)
- * PC2 - Open Drain output 50MHz (LED3)
+ * PC2 - Open Drain output 50MHz (LED3)
* PC3 - Analog input (ADC1)
* PC4 - Analog input (VBAT_MEAS)
* PC5 - Open Drain output 50MHz (LED4)
@@ -417,8 +417,8 @@
PIN_AFIO_AF(7, 2))
#define VAL_GPIOC_AFRH (PIN_AFIO_AF(8, 2) | \
PIN_AFIO_AF(9, 2) | \
- PIN_AFIO_AF(10, 7) | \
- PIN_AFIO_AF(11, 7) | \
+ PIN_AFIO_AF(10, 8) | \
+ PIN_AFIO_AF(11, 8) | \
PIN_AFIO_AF(12, 8) | \
PIN_AFIO_AF(13, 0) | \
PIN_AFIO_AF(14, 0) | \
@@ -1277,8 +1277,8 @@
*/
#define RC_PPM_TICKS_PER_USEC 6
#define PPM_TIMER_FREQUENCY 6000000
-#define PPM_CHANNEL ICU_CHANNEL_1
-#define PPM_TIMER ICUD1
+#define PPM_CHANNEL ICU_CHANNEL_2
+#define PPM_TIMER ICUD2
/**
* I2C defines
@@ -200,8 +200,8 @@
* PB4 - Open Drain output 50MHz (LED2)
* PB5 - Digital input (IMU_MAG_DRDY)
- * PB6 - Alternate Open Drain output 2MHz (SERVO7-Timer4Ch1)/USART1_TX
- * PB7 - Alternate Open Drain output 2MHz (SERVO8-Timer4Ch2)/USART1_RX
+ * PB6 - Alternate Push Pull output 50MHz (SERVO7-Timer4Ch1)/USART1_TX/I2C1_SCL
+ * PB7 - Alternate Push Pull output 50MHz (SERVO8-Timer4Ch2)/USART1_RX/I2C1_SDA
* PB8 - Digital input. (CAN_RX)
* PB9 - Open Drain output 50MHz. (CAN_TX)